@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-To run our analyzes, the KxY backend needs your data. The methods below are the only methods involved in sharing your data with us. The :code:`kxy` package only uploads your data `if` and `when` needed.
+To run our analyzes, the KXY backend needs your data. The methods below are the only methods involved in sharing your data with us. The :code:`kxy` package only uploads your data `if` and `when` needed.
 """
 import hashlib
 import logging
@@ -69,28 +69,47 @@ def upload_data(df):
 	d : bool
 		Whether the upload was successful.
 	"""
-	identifier = hashlib.sha256(df.to_string().encode()).hexdigest()
+	logging.debug('')
+	logging.debug('Hashing the data to form the file name')
+	content = pd.util.hash_pandas_object(df).to_string().encode()
+	identifier = hashlib.sha256(content).hexdigest()
+	logging.debug('Done hashing the data')
 
 	if UPLOADED_FILES.get(identifier, False):
 		logging.debug('The file with identifier %s was previously uplooaded' % identifier)
 		return identifier
 
+	logging.debug('Requesting a signed upload URL')
 	presigned_url = generate_upload_url(identifier)
 
 	if presigned_url is None:
+		logging.warning('Failed to retrieve the signed upload URL')
 		return None
+	else:
+		logging.debug('Signed upload URL retrieved')
 
 	if presigned_url == {}:
+		logging.debug('This file was previously uploaded')
 		UPLOADED_FILES[identifier] = True
 		return identifier
 
+	logging.debug('Preparing the data to upload')
 	file_name = identifier + '.csv'
-	files = {'file': (file_name, df.to_csv(index=False))}
+	memory_usage = df.memory_usage(index=False).sum()/(1024.0*1024.0*1024.0)
+	if memory_usage > 0.5:
+		# Truncate floats with excessive precision to save space.
+		files = {'file': (file_name, df.to_csv(index=False, float_format='%.7f'))}
+	else:
+		files = {'file': (file_name, df.to_csv(index=False))}
 	url = presigned_url['url']
 	data = presigned_url['fields']
+	logging.debug('Done preparing the data to upload')
+	
+	logging.debug('Uploading the data')
 	upload_response = requests.post(url, data=data, files=files)
 
 	if upload_response.status_code in [requests.codes.ok, requests.codes.created, requests.codes.accepted, requests.codes.no_content]:
+		logging.debug('Data successfully uploaded')
 		UPLOADED_FILES[identifier] = True
 		return identifier
 	else:
